==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFloatingPaneResizeMoveEventArgsDescription } from "./WebFloatingPaneResizeMoveEventArgsDescription";
/**
 * @hidden
 */
var WebFloatingPaneResizeMoveEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebFloatingPaneResizeMoveEventArgsDescriptionMetadata, _super);
    function WebFloatingPaneResizeMoveEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.b = function (a) {
        if (WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.a == null) {
            WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.c(WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.a);
        }
        if (a.g(WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.a);
        WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.d(a);
    };
    WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:FloatingPaneResizeMoveEventArgs");
        a.item("Detail", "ExportedType:WebFloatingPaneResizeMoveEventArgs");
    };
    WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.d = function (a) {
        WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.b(a);
        a.u("WebFloatingPaneResizeMoveEventArgs", function () { return new WebFloatingPaneResizeMoveEventArgsDescription(); });
        a.t("WebFloatingPaneResizeMoveEventArgs", WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.a);
    };
    WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.$t = markType(WebFloatingPaneResizeMoveEventArgsDescriptionMetadata, 'WebFloatingPaneResizeMoveEventArgsDescriptionMetadata');
    WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.a = null;
    return WebFloatingPaneResizeMoveEventArgsDescriptionMetadata;
}(Base));
export { WebFloatingPaneResizeMoveEventArgsDescriptionMetadata };

==> igniteui-react-core-18.0.0.tgz: package/esm5/lib/WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDockManagerPointDescriptionMetadata } from "./WebDockManagerPointDescriptionMetadata";
import { WebFloatingPaneResizeEventArgsDescriptionMetadata } from "./WebFloatingPaneResizeEventArgsDescriptionMetadata";
import { WebFloatingPaneResizeMoveEventArgsDescription } from "./WebFloatingPaneResizeMoveEventArgsDescription";
/**
 * @hidden
 */
var WebFloatingPaneResizeMoveEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebFloatingPaneResizeMoveEventArgsDescriptionMetadata, _super);
    function WebFloatingPaneResizeMoveEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.b = function (a) {
        if (WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.a == null) {
            WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.c(WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.a);
        }
        if (a.g(WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.a);
        WebDockManagerPointDescriptionMetadata.d(a);
    };
    WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.c = function (a) {
        WebFloatingPaneResizeEventArgsDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:FloatingPaneResizeMoveEventArgs");
        a.item("OldWidth", "Number:double");
        a.item("NewWidth", "Number:double");
        a.item("OldHeight", "Number:double");
        a.item("NewHeight", "Number:double");
        a.item("OldLocation", "ExportedType:WebDockManagerPoint");
        a.item("NewLocation", "ExportedType:WebDockManagerPoint");
    };
    WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.d = function (a) {
        WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.b(a);
        a.u("WebFloatingPaneResizeMoveEventArgs", function () { return new WebFloatingPaneResizeMoveEventArgsDescription(); });
        a.t("WebFloatingPaneResizeMoveEventArgs", WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.a);
    };
    WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.$t = markType(WebFloatingPaneResizeMoveEventArgsDescriptionMetadata, 'WebFloatingPaneResizeMoveEventArgsDescriptionMetadata');
    WebFloatingPaneResizeMoveEventArgsDescriptionMetadata.a = null;
    return WebFloatingPaneResizeMoveEventArgsDescriptionMetadata;
}(Base));
export { WebFloatingPaneResizeMoveEventArgsDescriptionMetadata };
